#include <iostream>
#include <stdlib.h>
#include <limits>

#include "statistics.h"
#include "disk_flow.h"


using namespace std;

//compute the euclidean error from two files (estimated and ground truth)
void compute_error(
    const char *fgt,
    const char *fin,
    float      &ee,
    float      &std_ee,
    const int   border = 0,
    const float min    = -99999,
    const float max    = 99999,
    const char *mask   = NULL
)
{
    int nx, ny;
   
    float *u1, *v1, *u2, *v2;
    float *m  = NULL;

    read_flow(fgt, &u1, &v1, nx, ny);
    read_flow(fin, &u2, &v2, nx, ny);

    if(mask != NULL)
        read_image(mask, &m, nx, ny);

    euclidean_error(u1, v1, u2, v2, nx, ny, ee, std_ee, border, min, max, m);

    delete []u1;
    delete []v1;
    delete []u2;
    delete []v2;

    if(m != NULL) delete []m;
}


int main(int argc, char *argv[])
{
    if(argc < 3)

        cout << "Usage: " << argv[0]
             << " gtflow eflow [border] [minvalue] [maxvalue] [mask]"
             << endl;
    else
    {
        int i = 1;

        //read the parameters
        const char *gtflow = argv[i]; i++;
        const char *eflow  = argv[i]; i++;

        int   border =  0;
        float min    = -999999.9;
        float max    =  999999.9;
        char *mask   =  NULL;

        if(argc > i) {border = atoi(argv[i]); i++;}
        if(argc > i) {min    = atof(argv[i]); i++;}
        if(argc > i) {max    = atof(argv[i]); i++;}
        if(argc > i) {mask   = argv[i];       i++;}

        float ee, std_ee;
        compute_error(
            gtflow, eflow, ee, std_ee,
            border, min, max, mask
        );

        std::cout << ee << " " << std_ee << endl;
    }

    return 0;
}
